@@ -12,8 +12,8 @@ sub import {
 
     enhance( $destination, $_, "fennec" ) for qw/
         tests describe it cases case before_each after_each around_each
-        before_all after_all around_all
-        /;
+        before_all after_all around_all before_case after_case
+    /;
 }
 
 1;
